
import '@/assets/css/iconfont.css'
import { ScrollView, Image } from '@tarojs/components'
import './index.scss'

export default function BasicInfo (props) {
  const { Info = {} } = props
  return (
    <view className='components BasicInfo'>

      {/* 标题名称 */}
      <view className='Title flex-h'>
        <view className='flex-item'>
          <text>{Info.buildingName}</text>
        </view>
        <view className='Collect'>
          <text className='iconfont icon-shoucang'></text>
          <text>收藏</text>
        </view>
      </view>

      {/* 标签 */}
      <view className='Tags'>
        {
          (Info.buildingTag || []).map((item, index) => (
            <text key={`TagItem-${index}`}>{item.tagName}</text>
          ))
        }
      </view>

      {/* 项目列表 */}
      <view className='ProjectList'>
        <ScrollView scroll-x>
          {
            (Info.buildingProjectType || []).map((item, index) => (
              <view className='ListItem' key={`List-${index}`}>
                <Image mode='heightFix' src={require('@/assets/buildingDetail-icon4.jpg')} />
                <view>
                  <view>
                    <text>项目类型：</text>
                    <text className='active black'>{item.buildingTypeName}</text>
                  </view>
                  <view>
                    <text>房屋产权：</text>
                    <text className='active'>{item.rightsYear}年</text>
                    <text>装修标准：</text>
                    <text className='active'>{item.decoration || '暂无'}</text>
                  </view>
                  <view>
                    <text>项目参考价格：</text>
                    {
                      (item.startPrice || item.endPrice) &&
                      <text className='active'>约{item.startPrice}-{item.endPrice}万/套</text>
                    }
                    {
                      !(item.startPrice || item.endPrice) &&
                      <text className='active'>暂无数据</text>
                    }
                  </view>
                  <text className='SaleStatus active'>{item.marketStatus}</text>
                </view>
              </view>
            ))
          }
        </ScrollView>
      </view>

      {/* 隔断 */}
      <view className='CutLine'></view>

      {/* 更多信息 */}
      <view className='MoreInfo'>
        <view className='flex-h'>
          <view className='flex-item'>
            <text>楼盘地址：</text>
          </view>
          <view className='flex-item3'>
            <text className='active'>{Info.address}</text>
          </view>
        </view>
        <view className='flex-h'>
          <view className='flex-item'>
            <text>开盘时间：</text>
          </view>
          <view className='flex-item3'>
            <text className='active'>{Info.openingDate || '待定'}</text>
          </view>
        </view>
        <view className='flex-h'>
          <view className='flex-item'>
            <text>容积率：</text>
          </view>
          <view className='flex-item'>
            <text className='active'>{Info.volumeRate || '暂无'}</text>
          </view>
          <view className='flex-item'>
            <text>车位比率：</text>
          </view>
          <view className='flex-item'>
            <text className='active'>{Info.parkingRate || '暂无'}</text>
          </view>
        </view>
        <view className='flex-h'>
          <view className='flex-item'>
            <text>绿化率：</text>
          </view>
          <view className='flex-item'>
            <text className='active'>{Info.greeningRate || '暂无'}</text>
          </view>
          <view className='flex-item'>
            <text>物业费：</text>
          </view>
          <view className='flex-item'>
            <text className='active'>{Info.serviceFee || '暂无'}</text>
          </view>
        </view>
        <view className='flex-h'>
          <view className='flex-item'>
            <text>规划户数：</text>
          </view>
          <view className='flex-item'>
            <text className='active'>{Info.familyNum || '暂无'}</text>
          </view>
          <view className='flex-item'>
            <text>物业：</text>
          </view>
          <view className='flex-item'>
            <text className='active'>{Info.serviceCompany || '暂无'}</text>
          </view>
        </view>
      </view>

      {/* 围观 */}
      <view className='Views flex-h'>
          <text>{Info.pvNum || 0}人围观</text>
          <view className='flex-item'>
            {
              (Info?.uvList?.records || []).slice(0, 8).map((item, index) => (
                <view key={`ViewsItem-${index}`}>
                  <Image mode='aspectFill' className='centerLabel' src={item.photoOravatar} />
                </view>
              ))
            }
            {
              (Info?.uvList?.records || []).length > 8 &&
              <text>...</text>
            }
          </view>
      </view>

      {/* 互动 */}
      <view className='Interact flex-h'>
        <text className='flex-item'>更多楼盘信息</text>
        <text className='flex-item active'>订阅活动通知</text>
      </view>

      {/* 提示 */}
      <view className='Tips'>
        <text className='iconfont icon-bangzhu'></text>
        <text>查看报备规则？</text>
      </view>

    </view>
  )
}
