import { useState, useEffect } from 'react'
import withLayout from '@/layout'
import { ScrollView } from '@tarojs/components'
import '@/assets/css/iconfont.css'
import { useSelector } from 'react-redux'
import { fetch } from '@/utils/request'
import { API_ITEMS_DETAIL } from '@/constants/api'
import './index.scss'
import DetailBottom from './components/DetailBottom/index'
import BasicInfo from './components/BasicInfo/index'
import SpecialPriceHouse from './components/SpecialPriceHouse/index'
import ProjectDynamic from './components/ProjectDynamic/index'
import PropertyConsultant from './components/PropertyConsultant/index'
import Periphery from './components/Periphery/index'
import HouseTypeIntro from './components/HouseTypeIntro/index'
import MarketingActivity from './components/MarketingActivity/index'
import LivingActivity from './components/LivingActivity/index'
import News from './components/News/index'
import Pictures from './components/Pictures/index'

export default withLayout((props) => {
  
  const user = useSelector(state => state.user)
  const [PersonId, setPersonId] = useState(null)
  const [DetailInfo, setDetailInfo] = useState({})
  const [IsPull, setPull] = useState(false)
  const [PullTimer, setPullTimer] = useState(null)

  useEffect(() => {
    if(user?.userInfo?.person?.personId) {
      setPersonId(user.userInfo.person.personId)
    }
  }, [user])

  useEffect(() => {
    if(PersonId) {
      GetBuildingDetail()
    }
  }, [PersonId])

  const GetBuildingDetail = () => { // 获取楼盘信息
    fetch({ url: `${API_ITEMS_DETAIL}/${props.router.params.id}`, method: 'get'}).then((res) => {
      setDetailInfo(res || {})
    })
  }

  const PageRefresh = () => { // 页面下拉刷新回调
    setPull(true)
  }

  useEffect(() => { // 下拉刷新触发
    if (IsPull) {
      clearTimeout(PullTimer)
      setPullTimer(setTimeout(() => {
        setPull(false)
      }, 2000))
    }
  }, [IsPull])

  return (
    <view className='Page buildingDetail flex-v'>

      <view className='flex-item'>
        <view>
          <ScrollView scroll-y refresher-enabled={false} refresher-triggered={IsPull} onrefresherrefresh={PageRefresh} refresher-background='#f8f8f8'>
            <view className='PageContent'>

              {/* banner */}
              <view className='BannerContainer'>
                <view>
                  <view>

                  </view>
                </view>
              </view>

              {/* content */}
              <view className='DetailContent'>

                {/* 基本信息 */}
                <view className='BasicInfo'>
                  <BasicInfo Info={DetailInfo}></BasicInfo>
                </view>

                {/* 特价房源 */}
                <view className='SpecialPriceHouse'>
                  <SpecialPriceHouse></SpecialPriceHouse>
                </view>

                {/* 项目动态 */}
                <view className='ProjectDynamic'>
                  <ProjectDynamic></ProjectDynamic>
                </view>

                {/* 置业顾问 */}
                <view className='PropertyConsultant'>
                  <PropertyConsultant></PropertyConsultant>
                </view>

                {/* 位置及周边 */}
                <view className='Periphery'>
                  <Periphery></Periphery>
                </view>

                {/* 户型介绍 */}
                <view className='HouseTypeIntro'>
                  <HouseTypeIntro></HouseTypeIntro>
                </view>

                {/* 营销活动 */}
                <view className='MarketingActivity'>
                  <MarketingActivity></MarketingActivity>
                </view>

                {/* 直播活动 */}
                <view className='LivingActivity'>
                  <LivingActivity></LivingActivity>
                </view>

                {/* 新鲜资讯 */}
                <view className='News'>
                  <News></News>
                </view>

                {/* 相册 */}
                <view className='Pictures'>
                  <Pictures></Pictures>
                </view>

              </view>

            </view>
          </ScrollView>
        </view>
      </view>

      <view className='PageBottom'>
        <DetailBottom></DetailBottom>
      </view>

    </view>
  )
})
