import { useState, useEffect } from 'react'
import { ScrollView } from '@tarojs/components'
import withLayout from '@/layout'
import { useSelector } from 'react-redux'
import { fetch } from '@/utils/request'
import { API_LIVE_LIST } from '@/constants/api'
import './index.scss'
import '../../assets/css/iconfont.css'
import VideoListItem from './components/VideoListItem/index'

export default withLayout(() => {

  const city = useSelector(state => state.city)
  const [IsPull, setPull] = useState(false)
  const [CurrnetMenuId, setCurrnetMenuId] = useState(null)
  const [MenuList] = useState([
    { name: '全部', id: 'all' },
    { name: '预告', id: 'notice' },
    { name: '直播中', id: 'live' },
    { name: '新房推荐', id: 'new' }
  ])
  const [PullTimer, setPullTimer] = useState(null)
  const [OriginList, setOriginList] = useState([])
  const [PageList, setPageList] = useState([])

  useEffect(() => {
    if (city.curCity.name) {
      setOriginList([])
      GetLiveList()
    }
  }, [city])

  useEffect(() => {
    if(OriginList.length && CurrnetMenuId === null) {
      setCurrnetMenuId('all')
    }
  }, [OriginList])

  useEffect(() => {
    if (CurrnetMenuId === 'all') {
      setPageList([...OriginList])
    } else {
      let Arr = []
      OriginList.map((item) => {
        if (CurrnetMenuId === 'new') {
          if(item.kind !== 'notice') {
            Arr.push({...item})
          }
        } else {
          if(item.kind === CurrnetMenuId) {
            Arr.push({...item})
          }
        }
      })
      setPageList([...Arr])
    }
  }, [CurrnetMenuId])

  const GetLiveList = () => {
    fetch({ url: API_LIVE_LIST, method: 'get', payload: { cityId: city.curCity.id, pageNum: 1, pageSize: 10000 } }).then((res) => {
      setOriginList(res.records || [])
    })
  }

  const PageRefresh = () => { // 页面下拉刷新回调
    setPull(true)
  }

  useEffect(() => { // 下拉刷新触发
    if (IsPull) {
      clearTimeout(PullTimer)
      setPullTimer(setTimeout(() => {
        setPull(false)
      }, 2000))
    }
  }, [IsPull])

  const CutMenu = (id) => {
    return () => {
      if (id !== CurrnetMenuId) {
        setCurrnetMenuId(id)
      }
    }
  }

  return (
    <view className='Page Video flex-v'>

      <view className='Search'>
        <view>
          <text className='iconfont icon-sousuo'></text>
          <text>输入项目名称或直播标题</text>
        </view>
      </view>

      <view className='Menu'>
        <view className='flex-h'>
          {
            MenuList.map((item, index) => (
              <view key={`MenuItem-${index}`} className={CurrnetMenuId === item.id ? 'active' : ''}>
                <text onClick={CutMenu(item.id)}>{item.name}</text>
              </view>
            ))
          }
        </view>
      </view>

      <view className='flex-item'>
        <view>
          <ScrollView scroll-y refresher-enabled refresher-triggered={IsPull} onrefresherrefresh={PageRefresh} refresher-background='#f8f8f8'>
            <view className='PageContent'>
              {
                PageList.map((item, index) => (
                  <view className='ListItem' key={`List-${index}`}>
                    <view>
                      <view>
                        <VideoListItem Data={item}></VideoListItem>
                      </view>
                    </view>
                  </view>
                ))
              }

              {/* bottom */}
              <view className='PageBottom'>
                <text>已经到底了~</text>
              </view>
            </view>
          </ScrollView>
        </view>
      </view>

    </view>
  )
})
